@@ -2,13 +2,12 @@
 
 import sys
 from json import loads
+
 from .util.file import get_local_file_content, get_remote_file_content
 from .util.module import create_empty_module, create_module_from_code
 
-from types import ModuleType
 
-
-def import_code(module_name: str, source_code: str, origin: str = None) -> ModuleType:
+def import_code(module_name, source_code, origin=None):
     """Imports python code as a module.
 
     Args:
@@ -20,7 +19,7 @@ def import_code(module_name: str, source_code: str, origin: str = None) -> Modul
         Python code imported as a module.
 
     Raises:
-        ImportError: Raised when the code can't be imported.
+        ValueError: When invalid module name is passed.
     """
     if not module_name.isidentifier():
         raise ValueError("Invalid module name.")
@@ -31,7 +30,7 @@ def import_code(module_name: str, source_code: str, origin: str = None) -> Modul
     return module
 
 
-def import_local_file(module_name: str, file_path: str) -> ModuleType:
+def import_local_file(module_name, file_path):
     """Imports a local file as a module.
 
     Args:
@@ -42,7 +41,7 @@ def import_local_file(module_name: str, file_path: str) -> ModuleType:
         File from the path imported as a module.
 
     Raises:
-        ImportError: Raised when the file can't be imported.
+        ValueError: When invalid module name is passed.
     """
     if not module_name.isidentifier():
         raise ValueError("Invalid module name.")
@@ -55,7 +54,7 @@ def import_local_file(module_name: str, file_path: str) -> ModuleType:
     return module
 
 
-def import_remote_file(module_name: str, url: str) -> ModuleType:
+def import_remote_file(module_name, url):
     """Imports a remote file as a module.
 
     Args:
@@ -66,7 +65,7 @@ def import_remote_file(module_name: str, url: str) -> ModuleType:
         File from the URL imported as a module.
 
     Raises:
-        ImportError: Raised when the file can't be imported.
+        ValueError: When invalid module name is passed.
     """
     if not module_name.isidentifier():
         raise ValueError("Invalid module name.")
@@ -79,7 +78,7 @@ def import_remote_file(module_name: str, url: str) -> ModuleType:
     return module
 
 
-def import_gist(module_name: str, gist_id: str) -> ModuleType:
+def import_gist(module_name, gist_id):
     """Imports a gist as a module.
 
     Args:
@@ -90,7 +89,7 @@ def import_gist(module_name: str, gist_id: str) -> ModuleType:
         Gist imported as a module.
 
     Raises:
-        ImportError: Raised when the gist can't be imported.
+        ValueError: When invalid module name is passed.
     """
     if not module_name.isidentifier():
         raise ValueError("Invalid module name.")
