@@ -1,7 +1,7 @@
 from urllib.request import urlopen
 
 
-def get_local_file_content(file_path: str) -> str:
+def get_local_file_content(file_path):
     """Gets the contents of a local file.
 
     Args:
@@ -11,11 +11,10 @@ def get_local_file_content(file_path: str) -> str:
         The content fetched from the local file.
     """
     with open(file_path, "r") as opened_file:
-        content: str = opened_file.read()
-        return content
+        return opened_file.read()
 
 
-def get_remote_file_content(url: str) -> str:
+def get_remote_file_content(url):
     """Gets the contents of a remote file.
 
     Args:
@@ -25,5 +24,4 @@ def get_remote_file_content(url: str) -> str:
         The content fetched from remote file.
     """
     with urlopen(url) as loaded_file:
-        content: str = loaded_file.read().decode("utf-8")
-        return content
+        return loaded_file.read().decode("utf-8")
